postgres.PostgresDocumentStream

|  | ## Cheshire3 Object Model: Class PostgresDocumentStream

Module postgres :: Class PostgresDocumentStream

## Class PostgresDocumentStream
source code

Object Tree:

    documentFactory.BaseDocumentStream --+
                                         |
                                        PostgresDocumentStream

Instance Methods

__init__(self, stream=None, format='', tag='', codec='')
find_documents(self, cache=0)
Inherited from `documentFactory.BaseDocumentStream`: `fetch_document`, `open_stream`

Class Variables

Inherited from `documentFactory.BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### __init__(self, stream=None, format='', tag='', codec='') (Constructor) | source code
Overrides: documentFactory.BaseDocumentStream.__init__

### find_documents(self, cache=0) | source code